test_that("Incorrect species in fetch_kegg", {
  expect_error(fetch_kegg())
  expect_error(fetch_kegg(1243))
  expect_error(fetch_kegg("not a species"))
})

test_that("Incorrect batch size in fetch_kegg", {
  expect_error(fetch_kegg("sce", "aha!"))
  expect_error(fetch_kegg("sce", -1))
  expect_error(fetch_kegg("sce", 0))
  expect_error(fetch_kegg("sce", 1000))
})


test_that("Parsing KEGG flat file", {
  # Temporary patch to circumvent vroom 1.6.4 bug
  readr::local_edition(1)

  flat <- readr::read_file("../test_data/kegg_test.txt")
  expected <- readr::read_rds("../test_data/kegg_parseing_result.rds")
  parsed <- parse_kegg_genes(flat)
  expect_equal(parsed, expected)
})


test_that("Expected return from fetch_kegg_species", {
  expected_selection <- c("hsa", "mmu", "rno", "sce", "dme", "cel")
  spec <- fetch_kegg_species()
  expect_is(spec, "tbl")
  expect_true(all(expected_selection %in% spec$designation))
})


test_that("Correct response from fetch_kegg", {
  species <- "mge"

  expected_terms <- tibble::tribble(
    ~term_id, ~term_name,
    "mge01100", "Metabolic pathways - Mycoplasmoides genitalium G37",
    "mge01230", "Biosynthesis of amino acids - Mycoplasmoides genitalium G37",
    "mge03010", "Ribosome - Mycoplasmoides genitalium G37",
    "mge03030", "DNA replication - Mycoplasmoides genitalium G37"
  )

  expected_mapping <- tibble::tribble(
    ~term_id, ~gene_symbol,
    "mge00010", "pgi",
    "mge00010", "fba",
    "mge03010", "rpsB",
    "mge03030", "polC"
  )

  re <- fetch_kegg(species)
  test_fetched_structure(re)
  test_terms(re$terms, expected_terms)
  test_mapping(re$mapping, expected_mapping, "gene_symbol")
})
